#!/bin/bash
set -e
# set -x
url="localhost:17782"

function checkHealth() {
  resp=$1
  code=$(echo $resp |grep -oP '"code":\K\d+'|| echo "")
  if [ "$code" != 200000 ]; then
    echo $resp
    echo "服务异常"
    exit 1
  fi
  echo "服务正常"
}

echo "common-登录"
loginResp=$(curl -s --request POST \
  --url http://${url}/api/v1/did-mgr/login \
  --header 'content-type: application/json' \
  --data '{
    "username":"admin",
    "password":"password"
}' || echo "")

checkHealth $loginResp
token=$(echo $loginResp |grep -oP "(?<=token\":\").*(?=\",\"expires)")

echo ""
echo "holder-kms-签名"
signResp=$(curl -s --request POST \
  --url http://${url}/api/v1/did-mgr/vp/sign \
  --header "content-type: application/json" \
  --header "x-token: ${token}" \
  --data '{
	"type": "VerifiablePresentation",
	"presentationUsage": "DID_GET_IDENTITY_VC_REQUEST",
	"expirationDate": "2054-04-20T16:56:46Z",
	"extend": {
		"fileID": "1",
		"fileName": "xx文件.pdf",
		"authorizedName": "xx平台"
	},
	"proof": [
		{
			"verificationMethod": ""
		}
	]
}'  || echo "")

checkHealth $signResp
sign=$(echo $signResp |grep -oP "(?<=data\":).*(?=\})")

echo ""
echo "common-验签"
verifyResp=$(curl -s --request POST \
  --url http://${url}/api/v1/did-mgr/vp/verify \
  --header 'content-type: application/json' \
  --header "x-token: ${token}" \
  --data "$sign" || echo "")

  
checkHealth $verifyResp

echo ""
echo "issuer-查询vc列表"
healthResp=$(curl -s --request POST \
  --url http://${url}/api/v1/did-mgr/vc/list/issued \
  --header 'content-type: application/json' \
  --header "x-token: ${token}" \
  --data '
	{"page": {
		"page": 1,
		"size": 20
	}}' || echo "")

checkHealth $healthResp